FlowMemberPicker class

@author lzj

@since 2022/11/28 16:29

选人组件

Inheritance

Constructors

FlowMemberPicker({Key? key, int limitNum = noLimit, bool allowEmpty = false, List<Members>? selectUserList, bool appBarVisible = true, bool? clickWithoutConfirm = false, String? title = "选择审批人/部门", String? searchHint = '请输入审批人/部门名称进行搜索', List<String>? indexList, OnSelected<Members>? onSelected, TileItemBuilder<Members>? itemBuilder, SelectedBuilder<Members>? selectedBuilder, bool? showSelectedList, bool refreshEnable = false, bool loadMoreEnable = false, bool showSearch = true, SearchRepo<RoleEntity, RoleEntity>? searchRepo, required List<Members>? originalList})

Properties

allowEmpty bool
是否允许不选择,如果不允许,则会在返回时提示用户选择
finalinherited
appBarVisible bool
finalinherited
clickWithoutConfirm bool?
finalinherited
controller → DUPickerController<Members, Members>?
finalinherited
crumbBuilder → CrumbBuilder<Members, Members>?
finalinherited
departmentBuilder → CrumbBuilder<Members, Members>?
finalinherited
departmentRepo → DepartmentRepo<Members>?
finalinherited
frozenList List<Members>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
indexList List<String>?
finalinherited
indexPredicate → IndexPredicate<Members, Members>?
finalinherited
isAutoLeading bool
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
limitNum int
选择限制数
finalinherited
loadMoreEnable bool
finalinherited
onBack VoidCallback?
返回按钮回调
finalinherited
onDataChanged VoidCallback?
列表数据改变回调
finalinherited
onParentSelect → dynamic Function(List<Members> parents)?
所有选择路径回调
finalinherited
onSelected → OnSelected<Members>?
finalinherited
onUserClick → OnUserClick<Members, Members>?
finalinherited
refreshEnable bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchHint String?
finalinherited
searchRepo → SearchRepo<Members, Members>?
finalinherited
selectUserList List<Members>?
finalinherited
separatorBuilder IndexedWidgetBuilder?
finalinherited
showIndex bool?
finalinherited
showSelectedList bool?
finalinherited
title String?
finalinherited
userRepo → UserRepo<Members, Members>?
finalinherited
userRepoPredication → UserRepoPredication<Members>?
用户列表是否可访问
finalinherited
userSelectedBuilder → SelectedBuilder<Members>?
finalinherited
userSelectorBuilder → UserSelectorBuilder<Members, Members>?
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DepartmentUserPicker<Members, Members>>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

pick(BuildContext context, Node node, {List<Members>? select}) Future<List<Members>?>