NodePickData class
Constructors
Properties
-
approveUserInfos
→ Map<
String, dynamic> ? -
no setter
- customCondition ↔ Map?
-
getter/setter pair
-
fullNodes
↔ List<
Node> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
members
↔ Map<
String, List< ?Members> ?> -
getter/setter pair
- nodeUserIds → Map?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedNodes
↔ List<
Node> ? -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited